@@ -31,9 +31,13 @@
 #include <QWidget>
 #include "Common.h"
 #include "DialogSettings.h"
+#include "FilterTextTranslator.h"
 #include "HtmlTranslator.h"
 
-BoolParameter::BoolParameter(QObject * parent) : AbstractParameter(parent, true), _default(false), _value(false), _label(nullptr), _checkBox(nullptr), _connected(false) {}
+namespace GmicQt
+{
+
+BoolParameter::BoolParameter(QObject * parent) : AbstractParameter(parent), _default(false), _value(false), _label(nullptr), _checkBox(nullptr), _connected(false) {}
 
 BoolParameter::~BoolParameter()
 {
@@ -41,6 +45,11 @@ BoolParameter::~BoolParameter()
   delete _label;
 }
 
+int BoolParameter::size() const
+{
+  return 1;
+}
+
 bool BoolParameter::addTo(QWidget * widget, int row)
 {
   _grid = dynamic_cast<QGridLayout *>(widget->layout());
@@ -61,11 +70,16 @@ bool BoolParameter::addTo(QWidget * widget, int row)
   return true;
 }
 
-QString BoolParameter::textValue() const
+QString BoolParameter::value() const
 {
   return _value ? QString("1") : QString("0");
 }
 
+QString BoolParameter::defaultValue() const
+{
+  return _default ? QString("1") : QString("0");
+}
+
 void BoolParameter::setValue(const QString & value)
 {
   _value = (value == "1");
@@ -110,7 +124,9 @@ bool BoolParameter::initFromText(const char * text, int & textLength)
   if (list.isEmpty()) {
     return false;
   }
-  _name = HtmlTranslator::html2txt(list[0]);
+  _name = HtmlTranslator::html2txt(FilterTextTranslator::translate(list[0]));
   _value = _default = (list[1].startsWith("true") || list[1].startsWith("1"));
   return true;
 }
+
+} // namespace GmicQt
