@@ -31,13 +31,18 @@
 class QComboBox;
 class QLabel;
 
+namespace GmicQt
+{
+
 class ChoiceParameter : public AbstractParameter {
   Q_OBJECT
 public:
   ChoiceParameter(QObject * parent = nullptr);
   ~ChoiceParameter() override;
+  virtual int size() const override;
   bool addTo(QWidget *, int row) override;
-  QString textValue() const override;
+  QString value() const override;
+  QString defaultValue() const override;
   void setValue(const QString &) override;
   void reset() override;
   bool initFromText(const char * text, int & textLength) override;
@@ -56,4 +61,6 @@ private:
   bool _connected;
 };
 
+} // namespace GmicQt
+
 #endif // GMIC_QT_CHOICEPARAMETER_H
