@@ -22,8 +22,8 @@
  *  along with gmic_qt.  If not, see <http://www.gnu.org/licenses/>.
  *
  */
-#ifndef _GMIC_QT_FILTERPARAMSWIDGET_H_
-#define _GMIC_QT_FILTERPARAMSWIDGET_H_
+#ifndef GMIC_QT_FILTERPARAMSWIDGET_H
+#define GMIC_QT_FILTERPARAMSWIDGET_H
 
 #include <QGroupBox>
 #include <QList>
@@ -33,17 +33,20 @@
 #include <QVector>
 #include <QWidget>
 #include "KeypointList.h"
-class AbstractParameter;
 class QLabel;
 
+namespace GmicQt
+{
+class AbstractParameter;
+
 class FilterParametersWidget : public QWidget {
   Q_OBJECT
 
 public:
   FilterParametersWidget(QWidget * parent = nullptr);
   bool build(const QString & name, const QString & hash, const QString & parameters, const QList<QString> & values, const QList<int> & visibilityStates);
-  void setNoFilter(const QString & message = QString::null);
-  virtual ~FilterParametersWidget();
+  void setNoFilter(const QString & message = QString());
+  ~FilterParametersWidget() override;
   const QString & valueString() const;
   QStringList valueStringList() const;
   void setValues(const QStringList &, bool notify);
@@ -60,9 +63,13 @@ public:
   KeypointList keypoints() const;
   void setKeypoints(KeypointList list, bool notify);
   bool hasKeypoints() const;
-  const QString & quotedParameters() const;
+  const QVector<bool> & quotedParameters() const;
 
-  static QString flattenParameterList(const QList<QString> & list, const QString & quoted);
+  static QString defaultValueString(const QVector<AbstractParameter *> & parameters);
+  static QStringList defaultParameterList(const QString & parameters,       //
+                                          QString * error,                  //
+                                          QVector<bool> * quoted = nullptr, //
+                                          QVector<int> * size = nullptr);
 
 public slots:
   void updateValueString(bool notify = true);
@@ -70,9 +77,16 @@ public slots:
 signals:
   void valueChanged();
 
+private:
+  static QString valueString(const QVector<AbstractParameter *> & parameters);
+  static QVector<AbstractParameter *> buildParameters(const QString & parameters, QObject * parent, int * actualParameterCount, QString * error);
+  static QStringList defaultParameterList(const QVector<AbstractParameter *> & parameters, QVector<bool> * quoted);
+  static QVector<bool> quotedParameters(const QVector<AbstractParameter *> & parameters);
+  static QVector<int> parameterSizes(const QVector<AbstractParameter *> & parameters);
+
 protected:
   void clear();
-  QVector<AbstractParameter *> _presetParameters;
+  QVector<AbstractParameter *> _parameters;
   int _actualParametersCount;
   QString _valueString;
   QLabel * _labelNoParams;
@@ -80,7 +94,9 @@ protected:
   QString _filterName;
   QString _filterHash;
   bool _hasKeypoints;
-  QString _quotedParameters;
+  QVector<bool> _quotedParameters;
 };
 
-#endif // _GMIC_QT_FILTERPARAMSWIDGET_H_
+} // namespace GmicQt
+
+#endif // GMIC_QT_FILTERPARAMSWIDGET_H
