@@ -27,16 +27,19 @@
 #include <QLabel>
 #include <QPalette>
 #include <QSlider>
-#include <QSpinBox>
 #include <QTimerEvent>
 #include <QWidget>
 #include "DialogSettings.h"
+#include "FilterParameters/CustomSpinBox.h"
 #include "FilterTextTranslator.h"
 #include "Globals.h"
 #include "HtmlTranslator.h"
 #include "Logger.h"
 
-IntParameter::IntParameter(QObject * parent) : AbstractParameter(parent, true), _min(0), _max(0), _default(0), _value(0), _label(nullptr), _slider(nullptr), _spinBox(nullptr)
+namespace GmicQt
+{
+
+IntParameter::IntParameter(QObject * parent) : AbstractParameter(parent), _min(0), _max(0), _default(0), _value(0), _label(nullptr), _slider(nullptr), _spinBox(nullptr)
 {
   _timerId = 0;
   _connected = false;
@@ -49,6 +52,11 @@ IntParameter::~IntParameter()
   delete _label;
 }
 
+int IntParameter::size() const
+{
+  return 1;
+}
+
 bool IntParameter::addTo(QWidget * widget, int row)
 {
   _grid = dynamic_cast<QGridLayout *>(widget->layout());
@@ -70,8 +78,7 @@ bool IntParameter::addTo(QWidget * widget, int row)
     _slider->setPageStep(fact * (delta / fact) / 10);
   }
 
-  _spinBox = new QSpinBox(widget);
-  _spinBox->setRange(_min, _max);
+  _spinBox = new CustomSpinBox(widget, _min, _max);
   _spinBox->setValue(_value);
   if (DialogSettings::darkThemeEnabled()) {
     QPalette p = _slider->palette();
@@ -83,14 +90,22 @@ bool IntParameter::addTo(QWidget * widget, int row)
   _grid->addWidget(_slider, row, 1, 1, 1);
   _grid->addWidget(_spinBox, row, 2, 1, 1);
   connectSliderSpinBox();
+
+  connect(_spinBox, &CustomSpinBox::editingFinished, [this]() { notifyIfRelevant(); });
+
   return true;
 }
 
-QString IntParameter::textValue() const
+QString IntParameter::value() const
 {
   return _spinBox->text();
 }
 
+QString IntParameter::defaultValue() const
+{
+  return QString::number(_default);
+}
+
 void IntParameter::setValue(const QString & value)
 {
   bool ok = true;
@@ -141,7 +156,9 @@ void IntParameter::timerEvent(QTimerEvent * e)
 {
   killTimer(e->timerId());
   _timerId = 0;
-  notifyIfRelevant();
+  if (not _spinBox->unfinishedKeyboardEditing()) {
+    notifyIfRelevant();
+  }
 }
 
 void IntParameter::onSliderMoved(int value)
@@ -165,7 +182,11 @@ void IntParameter::onSpinBoxChanged(int i)
   if (_timerId) {
     killTimer(_timerId);
   }
-  _timerId = startTimer(UPDATE_DELAY);
+  if (_spinBox->unfinishedKeyboardEditing()) {
+    _timerId = 0;
+  } else {
+    _timerId = startTimer(UPDATE_DELAY);
+  }
 }
 
 void IntParameter::connectSliderSpinBox()
@@ -188,3 +209,5 @@ void IntParameter::disconnectSliderSpinBox()
   _spinBox->disconnect(this);
   _connected = false;
 }
+
+} // namespace GmicQt
