@@ -27,17 +27,17 @@
 #include <QDebug>
 #include <limits>
 #include "Common.h"
+#include "FilterTextTranslator.h"
 #include "Globals.h"
 #include "HtmlTranslator.h"
-#include "Utils.h"
-#include "gmic_qt.h"
+#include "Misc.h"
+#include "GmicQt.h"
+
+namespace GmicQt
+{
 
 const size_t FiltersModel::NoIndex = std::numeric_limits<size_t>::max();
 
-FiltersModel::FiltersModel() = default;
-
-FiltersModel::~FiltersModel() = default;
-
 void FiltersModel::clear()
 {
   _hash2filter.clear();
@@ -81,6 +81,18 @@ const FiltersModel::Filter & FiltersModel::getFilterFromHash(const QString & has
   return _hash2filter.find(hash).value();
 }
 
+FiltersModel::const_iterator FiltersModel::findFilterFromAbsolutePath(const QString & path) const
+{
+  QString plainName = filterFullPathBasename(path);
+  for (auto it = cbegin(); it != cend(); ++it) {
+    // First test on plainText as plain(fullPath) is not immediate to compute
+    if ((it->plainText() == plainName) && (HtmlTranslator::html2txt(it->absolutePathNoTags()) == path)) {
+      return it;
+    }
+  }
+  return cend();
+}
+
 bool FiltersModel::contains(const QString & hash) const
 {
   return (_hash2filter.find(hash) != _hash2filter.cend());
@@ -101,7 +113,7 @@ void FiltersModel::removePath(const QList<QString> & path)
 
 FiltersModel::Filter::Filter()
 {
-  _previewFactor = GmicQt::PreviewFactorAny;
+  _previewFactor = PreviewFactorAny;
   _isAccurateIfZoomed = false;
   _isWarning = false;
 }
@@ -110,6 +122,7 @@ FiltersModel::Filter & FiltersModel::Filter::setName(const QString & name)
 {
   _name = name;
   _plainText = HtmlTranslator::html2txt(name, true);
+  _translatedPlainText = HtmlTranslator::html2txt(FilterTextTranslator::translate(name));
   return *this;
 }
 
@@ -147,8 +160,10 @@ FiltersModel::Filter & FiltersModel::Filter::setPath(const QList<QString> & path
 {
   _path = path;
   _plainPath.clear();
+  _translatedPlainPath.clear();
   for (const QString & str : _path) {
     _plainPath.push_back(HtmlTranslator::html2txt(str, true));
+    _translatedPlainPath.push_back(HtmlTranslator::html2txt(FilterTextTranslator::translate(str), true));
   }
   return *this;
 }
@@ -159,7 +174,7 @@ FiltersModel::Filter & FiltersModel::Filter::setWarningFlag(bool flag)
   return *this;
 }
 
-FiltersModel::Filter & FiltersModel::Filter::setDefaultInputMode(GmicQt::InputMode mode)
+FiltersModel::Filter & FiltersModel::Filter::setDefaultInputMode(InputMode mode)
 {
   _defaultInputMode = mode;
   return *this;
@@ -179,22 +194,32 @@ FiltersModel::Filter & FiltersModel::Filter::build()
   return *this;
 }
 
-QString FiltersModel::Filter::name() const
+const QString & FiltersModel::Filter::name() const
 {
   return _name;
 }
 
-QString FiltersModel::Filter::plainText() const
+const QString & FiltersModel::Filter::plainText() const
 {
   return _plainText;
 }
 
+const QString & FiltersModel::Filter::translatedPlainText() const
+{
+  return _translatedPlainText;
+}
+
 const QList<QString> & FiltersModel::Filter::path() const
 {
   return _path;
 }
 
-QString FiltersModel::Filter::hash() const
+const QString FiltersModel::Filter::absolutePathNoTags() const
+{
+  return filterFullPathWithoutTags(_path, _name);
+}
+
+const QString & FiltersModel::Filter::hash() const
 {
   return _hash;
 }
@@ -203,24 +228,24 @@ QString FiltersModel::Filter::hash236() const
 {
   QCryptographicHash hash(QCryptographicHash::Md5);
   QString lowerName(_name);
-  GmicQt::downcaseCommandTitle(lowerName);
+  downcaseCommandTitle(lowerName);
   hash.addData(lowerName.toLocal8Bit());
   hash.addData(_command.toLocal8Bit());
   hash.addData(_previewCommand.toLocal8Bit());
   return hash.result().toHex();
 }
 
-QString FiltersModel::Filter::command() const
+const QString & FiltersModel::Filter::command() const
 {
   return _command;
 }
 
-QString FiltersModel::Filter::previewCommand() const
+const QString & FiltersModel::Filter::previewCommand() const
 {
   return _previewCommand;
 }
 
-QString FiltersModel::Filter::parameters() const
+const QString & FiltersModel::Filter::parameters() const
 {
   return _parameters;
 }
@@ -240,7 +265,7 @@ bool FiltersModel::Filter::isWarning() const
   return _isWarning;
 }
 
-GmicQt::InputMode FiltersModel::Filter::defaultInputMode() const
+InputMode FiltersModel::Filter::defaultInputMode() const
 {
   return _defaultInputMode;
 }
@@ -252,12 +277,12 @@ bool FiltersModel::Filter::matchKeywords(const QList<QString> & keywords) const
     // Check that this keyword is present, either in filter name or in its path
     const QString & keyword = *itKeyword;
     bool keywordInPath = false;
-    QList<QString>::const_iterator itPath = _plainPath.cbegin();
-    while (itPath != _plainPath.cend() && !keywordInPath) {
+    QList<QString>::const_iterator itPath = _translatedPlainPath.cbegin();
+    while (itPath != _translatedPlainPath.cend() && !keywordInPath) {
       keywordInPath = itPath->contains(keyword, Qt::CaseInsensitive);
       ++itPath;
     }
-    if (!keywordInPath && !_plainText.contains(keyword, Qt::CaseInsensitive)) {
+    if (!keywordInPath && !_translatedPlainText.contains(keyword, Qt::CaseInsensitive)) {
       return false;
     }
     ++itKeyword;
@@ -313,3 +338,5 @@ bool FiltersModel::const_iterator::operator==(const FiltersModel::const_iterator
 {
   return _mapIterator == other._mapIterator;
 }
+
+} // namespace GmicQt
