@@ -29,22 +29,26 @@
 #include "FilterSelector/FiltersModel.h"
 #include "FilterSelector/FiltersView/FiltersView.h"
 #include "InputOutputState.h"
-#include "gmic_qt.h"
+#include "GmicQt.h"
 
 class QSettings;
 
+namespace GmicQt
+{
+
 class FiltersPresenter : public QObject {
   Q_OBJECT
 public:
   struct Filter {
     QString name;
     QString plainTextName;
+    QString fullPath;
     QString command;
     QString previewCommand;
     QString parameters;
     QList<QString> defaultParameterValues;
     QList<int> defaultVisibilityStates;
-    GmicQt::InputMode defaultInputMode;
+    InputMode defaultInputMode;
     QString hash;
     bool isAccurateIfZoomed;
     float previewFactor;
@@ -52,13 +56,14 @@ public:
     void clear();
     void setInvalid();
     bool isInvalid() const;
+    bool isValid() const;
     bool isNoApplyFilter() const;
     bool isNoPreviewFilter() const;
     const char * previewFactorString() const;
   };
 
   FiltersPresenter(QObject * parent);
-  ~FiltersPresenter();
+  ~FiltersPresenter() override;
   void setFiltersView(FiltersView * filtersView);
   void rebuildFilterView();
   void rebuildFilterViewWithSelection(const QList<QString> & keywords);
@@ -81,10 +86,14 @@ public:
   void restoreFaveHashLinksAfterCaseChange();
   void importGmicGTKFaves();
   void saveFaves();
-  void addSelectedFilterAsNewFave(const QList<QString> & defaultValues, const QList<int> & visibilityStates, GmicQt::InputOutputState inOutState);
+  void addSelectedFilterAsNewFave(const QList<QString> & defaultValues, const QList<int> & visibilityStates, InputOutputState inOutState);
 
   void applySearchCriterion(const QString & text);
   void selectFilterFromHash(QString hash, bool notify);
+  void selectFilterFromAbsolutePathOrPlainName(const QString & path);
+  void selectFilterFromAbsolutePath(QString path);
+  void selectFilterFromPlainName(const QString & name);
+  void selectFilterFromCommand(const QString & command);
   const Filter & currentFilter() const;
 
   void loadSettings(const QSettings & settings);
@@ -99,12 +108,19 @@ public:
 
   void expandAll();
   void collapseAll();
-
   const QString & errorMessage() const;
 
+  /**
+   * @brief findFilterFromPlainPathInStdlib
+   * Caution: this function parses the stdlib each time it is called
+   */
+  static Filter findFilterFromAbsolutePathOrNameInStdlib(const QString & path);
+  static Filter findFilterFromCommandInStdlib(const QString & command);
+
 signals:
   void filterSelectionChanged();
   void faveAdditionRequested(QString);
+  void faveNameChanged(QString);
 
 public slots:
   void removeSelectedFave();
@@ -118,6 +134,7 @@ private slots:
 
 private:
   void setCurrentFilter(const QString & hash);
+  bool filterExistsAsFave(const QString filterHash);
 
   FiltersModel _filtersModel;
   FavesModel _favesModel;
@@ -126,4 +143,6 @@ private:
   QString _errorMessage;
 };
 
+} // namespace GmicQt
+
 #endif // GMIC_QT_FILTERSPRESENTER_H
