@@ -40,6 +40,9 @@
 #include "Globals.h"
 #include "ui_filtersview.h"
 
+namespace GmicQt
+{
+
 const QString FiltersView::FilterTreePathSeparator("\t");
 
 FiltersView::FiltersView(QWidget * parent) : QWidget(parent), ui(new Ui::FiltersView), _isInSelectionMode(false)
@@ -467,6 +470,9 @@ void FiltersView::onItemChanged(QStandardItem * item)
     parentFolder = _model.invisibleRootItem();
   }
   QStandardItem * leftItem = parentFolder->child(row);
+  if (!leftItem) {
+    return;
+  }
   auto folder = dynamic_cast<FilterTreeFolder *>(leftItem);
   if (folder) {
     folder->applyVisibilityStatusToFolderContents();
@@ -608,6 +614,9 @@ QStandardItem * FiltersView::getFolderFromPath(QStandardItem * parent, QList<QSt
 
 void FiltersView::saveFiltersVisibility(QStandardItem * item)
 {
+  if (!item) {
+    return;
+  }
   auto filterItem = dynamic_cast<FilterTreeItem *>(item);
   if (filterItem) {
     FiltersVisibilityMap::setVisibility(filterItem->hash(), filterItem->isVisible());
@@ -630,3 +639,5 @@ FilterTreeItem * FiltersView::findFave(const QString & hash)
   }
   return nullptr;
 }
+
+} // namespace GmicQt
