@@ -33,6 +33,9 @@
 #include <deque>
 #include "Common.h"
 
+namespace GmicQt
+{
+
 class KeypointList {
 public:
   struct Keypoint {
@@ -112,4 +115,6 @@ int KeypointList::Keypoint::actualRadiusFromPreviewSize(const QSize & size) cons
   }
 }
 
+} // namespace GmicQt
+
 #endif // GMIC_QT_KEYPOINTLIST_H
