@@ -22,19 +22,21 @@
  *  along with gmic_qt.  If not, see <http://www.gnu.org/licenses/>.
  *
  */
-#ifndef _GMIC_QT_UTILS_H_
-#define _GMIC_QT_UTILS_H_
+#ifndef GMIC_QT_UTILS_H
+#define GMIC_QT_UTILS_H
 
-#include "gmic_qt.h"
+#include "GmicQt.h"
 class QString;
+class QStringList;
 
 namespace GmicQt
 {
-const QString & path_rc(bool create);
+
+const QString & gmicConfigPath(bool create);
 unsigned int host_app_pid();
 const QString & pluginFullName();
 const QString & pluginCodeName();
-const char * commandFromOutputMessageMode(OutputMessageMode mode);
+
 } // namespace GmicQt
 
-#endif // _GMIC_QT_UTILS_H_
+#endif // GMIC_QT_UTILS_H
